@@ -3,10 +3,11 @@ use wolf_engine::*;
 
 pub fn main() {
     #[cfg(feature = "logging")]
-    logging::initialize_logging(LevelFilter::Info);
+    logging::initialize_logging(LevelFilter::Debug);
 
     EngineBuilder::new()
         .with_plugin(Box::from(MessagePlugin::new("Hello, world!")))
+        .with_plugin(Box::from(FailurePlugin))
         .build()
         .run(Box::from(GameState));
 }
@@ -16,8 +17,8 @@ pub struct MessagePlugin {
 }
 
 impl Plugin for MessagePlugin {
-    fn setup(&mut self, engine_builder: EngineBuilder) -> EngineBuilder {
-        engine_builder.with_subcontext(MessageContext::new(self.message.clone()))
+    fn setup(&mut self, engine_builder: EngineBuilder) -> PluginResult {
+        Ok(engine_builder.with_subcontext(MessageContext::new(self.message.clone())))
     }
 }
 
@@ -29,6 +30,15 @@ impl MessagePlugin {
     }
 }
 
+pub struct FailurePlugin;
+
+impl Plugin for FailurePlugin {
+    fn setup(&mut self, engine_builder: EngineBuilder) -> PluginResult {
+        debug!("Intentionally returning an error.");
+        Err(("Something isn't right!", engine_builder))
+    }
+}
+
 pub struct MessageContext {
     message: String,
 }
